summaryrefslogtreecommitdiffstats
path: root/parts/bookmarks/bookmarks_part.h
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2014-05-25 15:37:31 +0900
commit6392f5a9dfce2bf83617d49bb7f332181ec6004e (patch)
treeab69e390f7962b7e7dda1a3a64f035c61c751cf4 /parts/bookmarks/bookmarks_part.h
parentaba2788b428dc53243407902e9ccbb20b97a69fd (diff)
downloadtdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.tar.gz
tdevelop-6392f5a9dfce2bf83617d49bb7f332181ec6004e.zip
Revert "Finish renaming tdevelop components"
This reverts commit 722ce1efbac31c61b1d4b13f7e075c9f311e3e73.
Diffstat (limited to 'parts/bookmarks/bookmarks_part.h')
-rw-r--r--parts/bookmarks/bookmarks_part.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/bookmarks/bookmarks_part.h b/parts/bookmarks/bookmarks_part.h
index b8015f54..f51603d7 100644
--- a/parts/bookmarks/bookmarks_part.h
+++ b/parts/bookmarks/bookmarks_part.h
@@ -10,8 +10,8 @@
***************************************************************************/
-#ifndef __TDEVPART_BOOKMARKS_H__
-#define __TDEVPART_BOOKMARKS_H__
+#ifndef __KDEVPART_BOOKMARKS_H__
+#define __KDEVPART_BOOKMARKS_H__
#include <tqguardedptr.h>
@@ -22,7 +22,7 @@
#include <tdeparts/part.h>
#include <kurl.h>
-#include <tdevplugin.h>
+#include <kdevplugin.h>
class TQTimer;
class KDialogBase;
@@ -38,7 +38,7 @@ struct EditorData
class BookmarksWidget;
class TQDomElement;
-class BookmarksPart : public TDevPlugin
+class BookmarksPart : public KDevPlugin
{
Q_OBJECT
@@ -48,7 +48,7 @@ public:
BookmarksPart(TQObject *parent, const char *name, const TQStringList &);
~BookmarksPart();
// reimplemented from TDevPlugin
void restorePartialProjectSession( const TQDomElement * el );
void savePartialProjectSession( TQDomElement * el );
@@ -48,7 +48,7 @@ public:
BookmarksPart(TQObject *parent, const char *name, const TQStringList &);
~BookmarksPart();
- // reimplemented from TDevPlugin
+ // reimplemented from KDevPlugin
void restorePartialProjectSession( const TQDomElement * el );
void savePartialProjectSession( TQDomElement * el );